@@ -1,20 +1,22 @@
 package XML::Feed;
 use strict;
+use warnings;
 
 use base qw( Class::ErrorHandler );
 use Feed::Find;
 use URI::Fetch;
 use LWP::UserAgent;
 use Carp;
+use Scalar::Util 'blessed';
 use Module::Pluggable search_path => "XML::Feed::Format",
                       require     => 1,
                       sub_name    => 'formatters';
 
-our $VERSION = '0.51';
+our $VERSION = '0.54';
 our $MULTIPLE_ENCLOSURES = 0;
 our @formatters;
 BEGIN {
-	@formatters = __PACKAGE__->formatters;
+    @formatters = __PACKAGE__->formatters;
 }
 
 sub new {
@@ -36,7 +38,7 @@ sub parse {
     return $class->error("Stream parameter is required") unless $stream;
     my $feed = bless {}, $class;
     my $xml = '';
-    if (UNIVERSAL::isa($stream, 'URI')) {
+    if (blessed($stream) and $stream->isa('URI')) {
         my $ua  = LWP::UserAgent->new;
         $ua->agent(__PACKAGE__ . "/$VERSION");
         $ua->env_proxy; # force allowing of proxies
@@ -52,7 +54,7 @@ sub parse {
             $xml .= $chunk;
         }
     } else {
-        open my $fh, $stream
+        open my $fh, '<', $stream
             or return $class->error("Can't open $stream: $!");
         while (read $fh, my($chunk), 8192) {
             $xml .= $chunk;
@@ -79,19 +81,19 @@ sub parse {
 sub identify_format {
     my $feed   = shift;
     my($xml)   = @_;
-	foreach my $class (@formatters) {
-		my ($name) = ($class =~ m!([^:]+)$!);
-		# TODO ugly
-		my $tmp = $$xml;
-		return $name if eval { $class->identify(\$tmp) };
-		return $feed->error($@) if $@;
-	} 
-	return $feed->error("Cannot detect feed type");
+    foreach my $class (@formatters) {
+        my ($name) = ($class =~ m!([^:]+)$!);
+        # TODO ugly
+        my $tmp = $$xml;
+        return $name if eval { $class->identify(\$tmp) };
+        return $feed->error($@) if $@;
+    }
+    return $feed->error("Cannot detect feed type");
 }
 
 sub _get_first_tag {
-	my $class  = shift;
-	my ($xml)  = @_;
+    my $class  = shift;
+    my ($xml)  = @_;
 
 
     ## Auto-detect feed type based on first element. This is prone
@@ -103,9 +105,9 @@ sub _get_first_tag {
         my $first = substr $t, 0, 1;
         $tag = $t, last unless $first eq '?' || $first eq '!';
     }
-	die ("Cannot find first element") unless $tag;
+    die ("Cannot find first element") unless $tag;
     $tag =~ s/^.*://;
-	return $tag;
+    return $tag;
 }
 
 sub find_feeds {
@@ -146,7 +148,7 @@ sub _convert_entry {
     my $feed_format  = ref($feed);   $feed_format  =~ s!^XML::Feed::Format::!!;
     my $entry_format = ref($entry);  $entry_format =~ s!^XML::Feed::Entry::Format::!!;
     return $entry if $entry_format eq $feed_format;
-    return $entry->convert($feed_format); 
+    return $entry->convert($feed_format);
 }
 
 sub base;
@@ -242,7 +244,7 @@ Creates a new empty I<XML::Feed> object using the format I<$format>.
 =head2 XML::Feed->parse($stream, $format)
 
 Parses a syndication feed identified by I<$stream> and returns an
-I<XML::Feed> obhect. I<$stream> can be any
+I<XML::Feed> object. I<$stream> can be any
 one of the following:
 
 =over 4
@@ -274,9 +276,10 @@ from that page (using I<E<lt>linkE<gt>> tags).
 
 Returns a list of feed URIs.
 
-=head2 XML::Feed->identify_format($xml)
+=head2 XML::Feed->identify_format(\$xml)
 
-Given the xml of a feed return what format it is in (C<Atom>, or some version of C<RSS>).
+Given the xml of a feed return what format it is in, with C<Atom> or C<RSS> for
+all versions of RSS.  Note that you pass in a scalar ref to the xml string.
 
 =head2 $feed->convert($format)
 
@@ -409,7 +412,7 @@ B<Note:> Only C<XML::RSS::LibXML> version 0.3004 is known to work at the moment.
 
 =item C<$XML::Feed::MULTIPLE_ENCLOSURES>
 
-Although the RSS specification states that there can be at most one enclosure per item 
+Although the RSS specification states that there can be at most one enclosure per item
 some feeds break this rule.
 
 If this variable is set then C<XML::Feed> captures all of them and makes them available as a list.
@@ -424,9 +427,9 @@ B<Note:> C<XML::RSS> version 1.44 is needed for this to work.
 
 =head1 VALID FEEDS
 
-For reference, this cgi script will create valid, albeit nonsensical feeds 
-(according to C<http://feedvalidator.org> anyway) for Atom 1.0 and RSS 0.90, 
-0.91, 1.0 and 2.0. 
+For reference, this cgi script will create valid, albeit nonsensical feeds
+(according to C<http://feedvalidator.org> anyway) for Atom 1.0 and RSS 0.90,
+0.91, 1.0 and 2.0.
 
     #!perl -w
 
