@@ -1,7 +1,8 @@
-# $Id$
-
 package XML::Feed::Format::RSS;
 use strict;
+use warnings;
+
+our $VERSION = '0.53';
 
 use base qw( XML::Feed );
 use DateTime::Format::Mail;
@@ -26,7 +27,7 @@ sub init_empty {
     eval "use $PREFERRED_PARSER"; die $@ if $@;
     $feed->{rss} = $PREFERRED_PARSER->new(%args);
     $feed->{rss}->add_module(prefix => "content", uri => 'http://purl.org/rss/1.0/modules/content/');
-    $feed->{rss}->add_module(prefix => "dcterms", uri => 'http://purl.org/dc/terms/');    
+    $feed->{rss}->add_module(prefix => "dcterms", uri => 'http://purl.org/dc/terms/');
     $feed->{rss}->add_module(prefix => "atom", uri => 'http://www.w3.org/2005/Atom');
     $feed->{rss}->add_module(prefix => "geo", uri => 'http://www.w3.org/2003/01/geo/wgs84_pos#');
     $feed;
@@ -104,13 +105,13 @@ sub self_link {
 }
 
 # This doesn't exist in RSS
-sub first_link { };
-sub last_link { };
-sub previous_link { };
-sub next_link { };
-sub current_link { };
-sub prev_archive_link { };
-sub next_archive_link { };
+sub first_link { }
+sub last_link { }
+sub previous_link { }
+sub next_link { }
+sub current_link { }
+sub prev_archive_link { }
+sub next_archive_link { }
 
 sub generator {
     my $feed = shift;
@@ -174,7 +175,7 @@ sub entries {
     my @entries;
     for my $item (@{ $rss->{items} }) {
         push @entries, XML::Feed::Entry::Format::RSS->wrap($item);
-		$entries[-1]->{_version} = $rss->{'version'};		
+        $entries[-1]->{_version} = $rss->{'version'};
     }
     @entries;
 }
